"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, authentication_profile_name: str, authentication_profile_content: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an authentication profile with the specified parameters.

    Args:
        authentication_profile_name(str): The name of the authentication profile to be created.
        authentication_profile_content(str): The content of the authentication profile in JSON format. The maximum length of the JSON string is determined by a quota for your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.authentication_profile.create(
                ctx, authentication_profile_name=value, authentication_profile_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.authentication_profile.create authentication_profile_name=value, authentication_profile_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_authentication_profile",
        op_kwargs={
            "AuthenticationProfileName": authentication_profile_name,
            "AuthenticationProfileContent": authentication_profile_content,
        },
    )


async def delete(hub, ctx, authentication_profile_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an authentication profile.

    Args:
        authentication_profile_name(str): The name of the authentication profile to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.authentication_profile.delete(
                ctx, authentication_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.authentication_profile.delete authentication_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_authentication_profile",
        op_kwargs={"AuthenticationProfileName": authentication_profile_name},
    )


async def describe_all(hub, ctx, authentication_profile_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes an authentication profile.

    Args:
        authentication_profile_name(str, optional): The name of the authentication profile to describe. If not specified then all authentication profiles owned by the account are listed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.authentication_profile.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.authentication_profile.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_authentication_profiles",
        op_kwargs={"AuthenticationProfileName": authentication_profile_name},
    )


async def modify(
    hub, ctx, authentication_profile_name: str, authentication_profile_content: str
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an authentication profile.

    Args:
        authentication_profile_name(str): The name of the authentication profile to replace.
        authentication_profile_content(str): The new content of the authentication profile in JSON format. The maximum length of the JSON string is determined by a quota for your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.authentication_profile.modify(
                ctx, authentication_profile_name=value, authentication_profile_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.authentication_profile.modify authentication_profile_name=value, authentication_profile_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_authentication_profile",
        op_kwargs={
            "AuthenticationProfileName": authentication_profile_name,
            "AuthenticationProfileContent": authentication_profile_content,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to the specified resource. You use tags to add metadata to resources, which you can use to categorize these resources. For example, you can categorize resources by purpose, owner, environment, or team. Each tag consists of a key and a value, which you define. You can add tags to the following Storage Gateway resources:   Storage gateways of all types   Storage volumes   Virtual tapes   NFS and SMB file shares   File System associations   You can create a maximum of 50 tags for each resource. Virtual tapes and storage volumes that are recovered to a new gateway maintain their tags.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource you want to add tags to.
        tags(List): The key-value pair that represents the tag you want to add to the resource. The value can be an empty string.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tags.to_resource.add(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tags.to_resource.add resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, cron_expression: str, name: str, job_names: List = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new schedule for one or more DataBrew jobs. Jobs can be run at a specific date and time, or at regular intervals.

    Args:
        job_names(List, optional): The name or names of one or more jobs to be run. Defaults to None.
        cron_expression(str): The date or dates and time or times when the jobs are to be run. For more information, see Cron expressions in the Glue DataBrew Developer Guide.
        tags(Dict, optional): Metadata tags to apply to this schedule. Defaults to None.
        name(str): A unique name for the schedule. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.schedule.create(ctx, cron_expression=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.schedule.create cron_expression=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_schedule",
        op_kwargs={
            "JobNames": job_names,
            "CronExpression": cron_expression,
            "Tags": tags,
            "Name": name,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified DataBrew schedule.

    Args:
        name(str): The name of the schedule to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.schedule.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.schedule.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="delete_schedule",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the definition of a specific DataBrew schedule.

    Args:
        name(str): The name of the schedule to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.schedule.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.schedule.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="describe_schedule",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub, ctx, job_name: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the DataBrew schedules that are defined.

    Args:
        job_name(str, optional): The name of the job that these schedules apply to. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.schedule.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.schedule.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_schedules",
        op_kwargs={
            "JobName": job_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, cron_expression: str, name: str, job_names: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of an existing DataBrew schedule.

    Args:
        job_names(List, optional): The name or names of one or more jobs to be run for this schedule. Defaults to None.
        cron_expression(str): The date or dates and time or times when the jobs are to be run. For more information, see Cron expressions in the Glue DataBrew Developer Guide.
        name(str): The name of the schedule to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.schedule.update(ctx, cron_expression=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.schedule.update cron_expression=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_schedule",
        op_kwargs={
            "JobNames": job_names,
            "CronExpression": cron_expression,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def submit(hub, ctx, attachments: List, cluster: str = None) -> Dict:
    r"""
    **Autogenerated function**

     This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent.  Sent to acknowledge that an attachment changed states.

    Args:
        cluster(str, optional): The short name or full ARN of the cluster that hosts the container instance the attachment belongs to. Defaults to None.
        attachments(List): Any attachments associated with the state change request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.attachment_state_change.submit(ctx, attachments=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.attachment_state_change.submit attachments=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="submit_attachment_state_changes",
        op_kwargs={"cluster": cluster, "attachments": attachments},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, parent_folder_id: str, authentication_token: str = None, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a folder with the specified name and parent folder.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        name(str, optional): The name of the new folder. Defaults to None.
        parent_folder_id(str): The ID of the parent folder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.init.create(ctx, parent_folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.init.create parent_folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="create_folder",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "Name": name,
            "ParentFolderId": parent_folder_id,
        },
    )


async def delete(hub, ctx, folder_id: str, authentication_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Permanently deletes the specified folder and its contents.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.init.delete(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.init.delete folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_folder",
        op_kwargs={"AuthenticationToken": authentication_token, "FolderId": folder_id},
    )


async def get(
    hub,
    ctx,
    folder_id: str,
    authentication_token: str = None,
    include_custom_metadata: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata of the specified folder.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
        include_custom_metadata(bool, optional): Set to TRUE to include custom metadata in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.init.get(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.init.get folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_folder",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "FolderId": folder_id,
            "IncludeCustomMetadata": include_custom_metadata,
        },
    )


async def update(
    hub,
    ctx,
    folder_id: str,
    authentication_token: str = None,
    name: str = None,
    parent_folder_id: str = None,
    resource_state: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the specified attributes of the specified folder. The user must have access to both the folder and its parent folder, if applicable.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
        name(str, optional): The name of the folder. Defaults to None.
        parent_folder_id(str, optional): The ID of the parent folder. Defaults to None.
        resource_state(str, optional): The resource state of the folder. Only ACTIVE and RECYCLED are accepted values from the API. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.init.update(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.init.update folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="update_folder",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "FolderId": folder_id,
            "Name": name,
            "ParentFolderId": parent_folder_id,
            "ResourceState": resource_state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    datastore_type_version: str,
    datastore_name: str = None,
    sse_configuration: Dict = None,
    preload_data_config: Dict = None,
    client_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Data Store that can ingest and export FHIR formatted data.

    Args:
        datastore_name(str, optional): The user generated name for the Data Store. Defaults to None.
        datastore_type_version(str): The FHIR version of the Data Store. The only supported version is R4.
        sse_configuration(Dict, optional):  The server-side encryption key configuration for a customer provided encryption key specified for creating a Data Store. . Defaults to None.
        preload_data_config(Dict, optional): Optional parameter to preload data upon creation of the Data Store. Currently, the only supported preloaded data is synthetic data generated from Synthea. Defaults to None.
        client_token(str, optional): Optional user provided token used for ensuring idempotency. Defaults to None.
        tags(List, optional):  Resource tags that are applied to a Data Store when it is created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.datastore.create(
                ctx, datastore_type_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.datastore.create datastore_type_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="create_fhir_datastore",
        op_kwargs={
            "DatastoreName": datastore_name,
            "DatastoreTypeVersion": datastore_type_version,
            "SseConfiguration": sse_configuration,
            "PreloadDataConfig": preload_data_config,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, datastore_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Data Store.

    Args:
        datastore_id(str, optional):  The AWS-generated ID for the Data Store to be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.datastore.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.datastore.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="delete_fhir_datastore",
        op_kwargs={"DatastoreId": datastore_id},
    )


async def describe(hub, ctx, datastore_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with the FHIR Data Store, including the Data Store ID, Data Store ARN, Data Store name, Data Store status, created at, Data Store type version, and Data Store endpoint.

    Args:
        datastore_id(str, optional): The AWS-generated Data Store id. This is part of the ‘CreateFHIRDatastore’ output. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.datastore.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.datastore.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="describe_fhir_datastore",
        op_kwargs={"DatastoreId": datastore_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all FHIR Data Stores that are in the user’s account, regardless of Data Store status.

    Args:
        filter_(Dict, optional): Lists all filters associated with a FHIR Data Store request. Defaults to None.
        next_token(str, optional): Fetches the next page of Data Stores when results are paginated. Defaults to None.
        max_results(int, optional): The maximum number of Data Stores returned in a single page of a ListFHIRDatastoresRequest call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.datastore.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.datastore.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="list_fhir_datastores",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, attribute_names: List = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes attributes of your AWS account. The following are the supported account attributes:    supported-platforms: Indicates whether your account can launch instances into EC2-Classic and EC2-VPC, or only into EC2-VPC.    default-vpc: The ID of the default VPC for your account, or none.    max-instances: This attribute is no longer supported. The returned value does not reflect your actual vCPU limit for running On-Demand Instances. For more information, see On-Demand Instance Limits in the Amazon Elastic Compute Cloud User Guide.    vpc-max-security-groups-per-interface: The maximum number of security groups that you can assign to a network interface.    max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-Classic.     vpc-max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-VPC.

    Args:
        attribute_names(List, optional): The account attribute names. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.account_attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.account_attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_account_attributes",
        op_kwargs={"AttributeNames": attribute_names, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def disable(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Disables AWS Health from working with AWS Organizations. To call this operation, you must sign in as an AWS Identity and Access Management (IAM) user, assume an IAM role, or sign in as the root user (not recommended) in the organization's management account. For more information, see Aggregating AWS Health events in the AWS Health User Guide. This operation doesn't remove the service-linked role from the management account in your organization. You must use the IAM console, API, or AWS Command Line Interface (AWS CLI) to remove the service-linked role. For more information, see Deleting a Service-Linked Role in the IAM User Guide.  You can also disable the organizational feature by using the Organizations DisableAWSServiceAccess API operation. After you call this operation, AWS Health stops aggregating events for all other AWS accounts in your organization. If you call the AWS Health API operations for organizational view, AWS Health returns an error. AWS Health continues to aggregate health events for your AWS account.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.health_service.access_for_organization.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.health_service.access_for_organization.disable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="disable_health_service_access_for_organization",
        op_kwargs={},
    )


async def enable(hub, ctx) -> None:
    r"""
    **Autogenerated function**

    Enables AWS Health to work with AWS Organizations. You can use the organizational view feature to aggregate events from all AWS accounts in your organization in a centralized location.  This operation also creates a service-linked role for the management account in the organization.   To call this operation, you must meet the following requirements:   You must have a Business or Enterprise Support plan from AWS Support to use the AWS Health API. If you call the AWS Health API from an AWS account that doesn't have a Business or Enterprise Support plan, you receive a SubscriptionRequiredException error.   You must have permission to call this operation from the organization's management account. For example IAM policies, see AWS Health identity-based policy examples.    If you don't have the required support plan, you can instead use the AWS Health console to enable the organizational view feature. For more information, see Aggregating AWS Health events in the AWS Health User Guide.

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.health_service.access_for_organization.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.health_service.access_for_organization.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="enable_health_service_access_for_organization",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, web_acl_arn: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a web ACL with a regional application resource, to protect the resource. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  For Amazon CloudFront, don't use this call. Instead, use your CloudFront distribution configuration. To associate a web ACL, in the CloudFront call UpdateDistribution, set the web ACL ID to the Amazon Resource Name (ARN) of the web ACL. For information, see UpdateDistribution.

    Args:
        web_acl_arn(str): The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to associate with the web ACL.  The ARN must be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Amazon API Gateway REST API: arn:aws:apigateway:region::/restapis/api-id/stages/stage-name     For an AppSync GraphQL API: arn:aws:appsync:region:account-id:apis/GraphQLApiId    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.associate(
                ctx, web_acl_arn=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.associate web_acl_arn=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="associate_web_acl",
        op_kwargs={"WebACLArn": web_acl_arn, "ResourceArn": resource_arn},
    )


async def create(
    hub,
    ctx,
    name: str,
    scope: str,
    default_action: Dict,
    visibility_config: Dict,
    description: str = None,
    rules: List = None,
    tags: List = None,
    custom_response_bodies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a WebACL per the specifications provided.  A web ACL defines a collection of rules to use to inspect and control web requests. Each rule has an action defined (allow, block, or count) for requests that match the statement of the rule. In the web ACL, you assign a default action to take (allow, block) for any request that does not match any of the rules. The rules in a web ACL can be a combination of the types Rule, RuleGroup, and managed rule group. You can associate a web ACL with one or more Amazon Web Services resources to protect. The resources can be an Amazon CloudFront distribution, an Amazon API Gateway REST API, an Application Load Balancer, or an AppSync GraphQL API.

    Args:
        name(str): The name of the web ACL. You cannot change the name of a web ACL after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        default_action(Dict): The action to perform if none of the Rules contained in the WebACL match. .
        description(str, optional): A description of the web ACL that helps with identification. . Defaults to None.
        rules(List, optional): The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them. . Defaults to None.
        visibility_config(Dict): Defines and enables Amazon CloudWatch metrics and web request sample collection. .
        tags(List, optional): An array of key:value pairs to associate with the resource. Defaults to None.
        custom_response_bodies(Dict, optional): A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the web ACL, and then use them in the rules and default actions that you define in the web ACL.  For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.  For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.create(
                ctx, name=value, scope=value, default_action=value, visibility_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.create name=value, scope=value, default_action=value, visibility_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="create_web_acl",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "DefaultAction": default_action,
            "Description": description,
            "Rules": rules,
            "VisibilityConfig": visibility_config,
            "Tags": tags,
            "CustomResponseBodies": custom_response_bodies,
        },
    )


async def delete(hub, ctx, name: str, scope: str, id_: str, lock_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified WebACL. You can only use this if ManagedByFirewallManager is false in the specified WebACL.

    Args:
        name(str): The name of the web ACL. You cannot change the name of a web ACL after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.delete(
                ctx, name=value, scope=value, id_=value, lock_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.delete name=value, scope=value, id_=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_web_acl",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_, "LockToken": lock_token},
    )


async def disassociate(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a web ACL from a regional application resource. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  For Amazon CloudFront, don't use this call. Instead, use your CloudFront distribution configuration. To disassociate a web ACL, provide an empty web ACL ID in the CloudFront call UpdateDistribution. For information, see UpdateDistribution.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to disassociate from the web ACL.  The ARN must be in one of the following formats:   For an Application Load Balancer: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id     For an Amazon API Gateway REST API: arn:aws:apigateway:region::/restapis/api-id/stages/stage-name     For an AppSync GraphQL API: arn:aws:appsync:region:account-id:apis/GraphQLApiId    .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.disassociate(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.disassociate resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="disassociate_web_acl",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, name: str, scope: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified WebACL.

    Args:
        name(str): The name of the web ACL. You cannot change the name of a web ACL after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.get(ctx, name=value, scope=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.get name=value, scope=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_web_acl",
        op_kwargs={"Name": name, "Scope": scope, "Id": id_},
    )


async def list_all(
    hub, ctx, scope: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of WebACLSummary objects for the web ACLs that you manage.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.list_all(ctx, scope=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.list_all scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_web_acls",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub,
    ctx,
    name: str,
    scope: str,
    id_: str,
    default_action: Dict,
    visibility_config: Dict,
    lock_token: str,
    description: str = None,
    rules: List = None,
    custom_response_bodies: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified WebACL.  This operation completely replaces the mutable specifications that you already have for the web ACL with the ones that you provide to this call. To modify the web ACL, retrieve it by calling GetWebACL, update the settings as needed, and then provide the complete web ACL specification to this call.   A web ACL defines a collection of rules to use to inspect and control web requests. Each rule has an action defined (allow, block, or count) for requests that match the statement of the rule. In the web ACL, you assign a default action to take (allow, block) for any request that does not match any of the rules. The rules in a web ACL can be a combination of the types Rule, RuleGroup, and managed rule group. You can associate a web ACL with one or more Amazon Web Services resources to protect. The resources can be an Amazon CloudFront distribution, an Amazon API Gateway REST API, an Application Load Balancer, or an AppSync GraphQL API.

    Args:
        name(str): The name of the web ACL. You cannot change the name of a web ACL after you create it.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        id_(str): The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        default_action(Dict): The action to perform if none of the Rules contained in the WebACL match. .
        description(str, optional): A description of the web ACL that helps with identification. . Defaults to None.
        rules(List, optional): The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them. . Defaults to None.
        visibility_config(Dict): Defines and enables Amazon CloudWatch metrics and web request sample collection. .
        lock_token(str): A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation. .
        custom_response_bodies(Dict, optional): A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the web ACL, and then use them in the rules and default actions that you define in the web ACL.  For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.  For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.web_acl.init.update(
                ctx,
                name=value,
                scope=value,
                id_=value,
                default_action=value,
                visibility_config=value,
                lock_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.web_acl.init.update name=value, scope=value, id_=value, default_action=value, visibility_config=value, lock_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="update_web_acl",
        op_kwargs={
            "Name": name,
            "Scope": scope,
            "Id": id_,
            "DefaultAction": default_action,
            "Description": description,
            "Rules": rules,
            "VisibilityConfig": visibility_config,
            "LockToken": lock_token,
            "CustomResponseBodies": custom_response_bodies,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified batch prediction job.

    Args:
        job_id(str): The ID of the batch prediction job to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.batch_prediction_job.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.batch_prediction_job.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="cancel_batch_prediction_job",
        op_kwargs={"jobId": job_id},
    )


async def create(
    hub,
    ctx,
    job_id: str,
    input_path: str,
    output_path: str,
    event_type_name: str,
    detector_name: str,
    iam_role_arn: str,
    detector_version: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a batch prediction job.

    Args:
        job_id(str): The ID of the batch prediction job.
        input_path(str): The Amazon S3 location of your training file.
        output_path(str): The Amazon S3 location of your output file.
        event_type_name(str): The name of the event type.
        detector_name(str): The name of the detector.
        detector_version(str, optional): The detector version. Defaults to None.
        iam_role_arn(str): The ARN of the IAM role to use for this job request.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.batch_prediction_job.create(
                ctx,
                job_id=value,
                input_path=value,
                output_path=value,
                event_type_name=value,
                detector_name=value,
                iam_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.batch_prediction_job.create job_id=value, input_path=value, output_path=value, event_type_name=value, detector_name=value, iam_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_batch_prediction_job",
        op_kwargs={
            "jobId": job_id,
            "inputPath": input_path,
            "outputPath": output_path,
            "eventTypeName": event_type_name,
            "detectorName": detector_name,
            "detectorVersion": detector_version,
            "iamRoleArn": iam_role_arn,
            "tags": tags,
        },
    )


async def delete(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a batch prediction job.

    Args:
        job_id(str): The ID of the batch prediction job to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.batch_prediction_job.delete(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.batch_prediction_job.delete job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_batch_prediction_job",
        op_kwargs={"jobId": job_id},
    )


async def get_all(
    hub, ctx, job_id: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all batch prediction jobs or a specific job if you specify a job ID. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 1 and 50. To get the next page results, provide the pagination token from the GetBatchPredictionJobsResponse as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        job_id(str, optional): The batch prediction job for which to get the details. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. Defaults to None.
        next_token(str, optional): The next token from the previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.batch_prediction_job.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.batch_prediction_job.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_batch_prediction_jobs",
        op_kwargs={"jobId": job_id, "maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, account_id: str, service_principal: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified member AWS account as a delegated administrator for the specified AWS service.  Deregistering a delegated administrator can have unintended impacts on the functionality of the enabled AWS service. See the documentation for the enabled service before you deregister a delegated administrator so that you understand any potential impacts.  You can run this action only for AWS services that support this feature. For a current list of services that support it, see the column Supports Delegated Administrator in the table at AWS Services that you can use with AWS Organizations in the AWS Organizations User Guide.  This operation can be called only from the organization's management account.

    Args:
        account_id(str): The account ID number of the member account in the organization that you want to deregister as a delegated administrator.
        service_principal(str): The service principal name of an AWS service for which the account is a delegated administrator. Delegated administrator privileges are revoked for only the specified AWS service from the member account. If the specified service is the only service for which the member account is a delegated administrator, the operation also revokes Organizations read action permissions.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.delegated.administrator.deregister(
                ctx, account_id=value, service_principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.delegated.administrator.deregister account_id=value, service_principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="deregister_delegated_administrator",
        op_kwargs={"AccountId": account_id, "ServicePrincipal": service_principal},
    )


async def list_all(
    hub,
    ctx,
    service_principal: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AWS accounts that are designated as delegated administrators in this organization. This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        service_principal(str, optional): Specifies a service principal name. If specified, then the operation lists the delegated administrators only for the specified service. If you don't specify a service principal, the operation lists all delegated administrators for all services in your organization. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Organizations might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.delegated.administrator.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.delegated.administrator.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_delegated_administrators",
        op_kwargs={
            "ServicePrincipal": service_principal,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def register(hub, ctx, account_id: str, service_principal: str) -> None:
    r"""
    **Autogenerated function**

    Enables the specified member account to administer the Organizations features of the specified AWS service. It grants read-only access to AWS Organizations service data. The account still requires IAM permissions to access and administer the AWS service. You can run this action only for AWS services that support this feature. For a current list of services that support it, see the column Supports Delegated Administrator in the table at AWS Services that you can use with AWS Organizations in the AWS Organizations User Guide.  This operation can be called only from the organization's management account.

    Args:
        account_id(str): The account ID number of the member account in the organization to register as a delegated administrator.
        service_principal(str): The service principal of the AWS service for which you want to make the member account a delegated administrator.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.delegated.administrator.register(
                ctx, account_id=value, service_principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.delegated.administrator.register account_id=value, service_principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="register_delegated_administrator",
        op_kwargs={"AccountId": account_id, "ServicePrincipal": service_principal},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.

    Args:
        name(str): The name of the partner event source to activate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.source.activate(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.source.activate name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="activate_event_source",
        op_kwargs={"Name": name},
    )


async def deactivate(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    You can use this operation to temporarily stop receiving events from the specified partner event source. The matching event bus is not deleted.  When you deactivate a partner event source, the source goes into PENDING state. If it remains in PENDING state for more than two weeks, it is deleted. To activate a deactivated partner event source, use ActivateEventSource.

    Args:
        name(str): The name of the partner event source to deactivate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.source.deactivate(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.source.deactivate name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="deactivate_event_source",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists details about a partner event source that is shared with your account.

    Args:
        name(str): The name of the partner event source to display the details of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.source.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.source.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_event_source",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub, ctx, name_prefix: str = None, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    You can use this to see all the partner event sources that have been shared with your AWS account. For more information about partner event sources, see CreateEventBus.

    Args:
        name_prefix(str, optional): Specifying this limits the results to only those partner event sources with names that start with the specified prefix. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): Specifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.source.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.source.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_event_sources",
        op_kwargs={"NamePrefix": name_prefix, "NextToken": next_token, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    project_arn: str,
    name: str,
    rules: List,
    description: str = None,
    max_devices: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a device pool.

    Args:
        project_arn(str): The ARN of the project for the device pool.
        name(str): The device pool's name.
        description(str, optional): The device pool's description. Defaults to None.
        rules(List): The device pool's rules.
        max_devices(int, optional): The number of devices that Device Farm can add to your device pool. Device Farm adds devices that are available and meet the criteria that you assign for the rules parameter. Depending on how many devices meet these constraints, your device pool might contain fewer devices than the value for this parameter. By specifying the maximum number of devices, you can control the costs that you incur by running tests. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.init.create(
                ctx, project_arn=value, name=value, rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.init.create project_arn=value, name=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_device_pool",
        op_kwargs={
            "projectArn": project_arn,
            "name": name,
            "description": description,
            "rules": rules,
            "maxDevices": max_devices,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a device pool given the pool ARN. Does not allow deletion of curated pools owned by the system.

    Args:
        arn(str): Represents the Amazon Resource Name (ARN) of the Device Farm device pool to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.init.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.init.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_device_pool",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a device pool.

    Args:
        arn(str): The device pool's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.init.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.init.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_device_pool",
        op_kwargs={"arn": arn},
    )


async def list_all(
    hub, ctx, arn: str, type_: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about device pools.

    Args:
        arn(str): The project ARN.
        type_(str, optional): The device pools' type. Allowed values include:   CURATED: A device pool that is created and managed by AWS Device Farm.   PRIVATE: A device pool that is created and managed by the device pool developer.  . Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.init.list_all(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.init.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_device_pools",
        op_kwargs={"arn": arn, "type": type_, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    description: str = None,
    rules: List = None,
    max_devices: int = None,
    clear_max_devices: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the name, description, and rules in a device pool given the attributes and the pool ARN. Rule updates are all-or-nothing, meaning they can only be updated as a whole (or not at all).

    Args:
        arn(str): The Amazon Resource Name (ARN) of the Device Farm device pool to update.
        name(str, optional): A string that represents the name of the device pool to update. Defaults to None.
        description(str, optional): A description of the device pool to update. Defaults to None.
        rules(List, optional): Represents the rules to modify for the device pool. Updating rules is optional. If you update rules for your request, the update replaces the existing rules. Defaults to None.
        max_devices(int, optional): The number of devices that Device Farm can add to your device pool. Device Farm adds devices that are available and that meet the criteria that you assign for the rules parameter. Depending on how many devices meet these constraints, your device pool might contain fewer devices than the value for this parameter. By specifying the maximum number of devices, you can control the costs that you incur by running tests. If you use this parameter in your request, you cannot use the clearMaxDevices parameter in the same request. Defaults to None.
        clear_max_devices(bool, optional): Sets whether the maxDevices parameter applies to your device pool. If you set this parameter to true, the maxDevices parameter does not apply, and Device Farm does not limit the number of devices that it adds to your device pool. In this case, Device Farm adds all available devices that meet the criteria specified in the rules parameter. If you use this parameter in your request, you cannot use the maxDevices parameter in the same request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.init.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.init.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_device_pool",
        op_kwargs={
            "arn": arn,
            "name": name,
            "description": description,
            "rules": rules,
            "maxDevices": max_devices,
            "clearMaxDevices": clear_max_devices,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def group(hub, ctx, group: str, resource_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified resources to the specified group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:GroupResources

    Args:
        group(str): The name or the ARN of the resource group to add resources to.
        resource_arns(List): The list of ARNs for resources to be added to the group. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.resource.group(
                ctx, group=value, resource_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.resource.group group=value, resource_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="group_resources",
        op_kwargs={"Group": group, "ResourceArns": resource_arns},
    )


async def search(
    hub, ctx, resource_query: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of AWS resource identifiers that matches the specified query. The query uses the same format as a resource query in a CreateGroup or UpdateGroupQuery operation.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:SearchResources     cloudformation:DescribeStacks     cloudformation:ListStackResources     tag:GetResources

    Args:
        resource_query(Dict): The search query, using the same formats that are supported for resource group definition. For more information, see CreateGroup.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.resource.search(ctx, resource_query=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.resource.search resource_query=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="search_resources",
        op_kwargs={
            "ResourceQuery": resource_query,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def ungroup(hub, ctx, group: str, resource_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified resources from the specified group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:UngroupResources

    Args:
        group(str): The name or the ARN of the resource group from which to remove the resources.
        resource_arns(List): The ARNs of the resources to be removed from the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.resource.ungroup(
                ctx, group=value, resource_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.resource.ungroup group=value, resource_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="ungroup_resources",
        op_kwargs={"Group": group, "ResourceArns": resource_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Creates a bucket in Amazon S3 to store application versions, logs, and other files used by Elastic Beanstalk environments. The Elastic Beanstalk console and EB CLI call this API the first time you create an environment in a region. If the storage location already exists, CreateStorageLocation still returns the bucket name but does not create a new bucket.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.storage_location.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.storage_location.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_storage_location",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def replace(
    hub, ctx, association_id: str, network_acl_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes which network ACL a subnet is associated with. By default when you create a subnet, it's automatically associated with the default network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide. This is an idempotent operation.

    Args:
        association_id(str): The ID of the current association between the original network ACL and the subnet.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_acl_id(str): The ID of the new network ACL to associate with the subnet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.association.replace(
                ctx, association_id=value, network_acl_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.association.replace association_id=value, network_acl_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="replace_network_acl_association",
        op_kwargs={
            "AssociationId": association_id,
            "DryRun": dry_run,
            "NetworkAclId": network_acl_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str = None,
    latency_mode: str = None,
    type_: str = None,
    authorized: bool = None,
    recording_configuration_arn: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new channel and an associated stream key to start streaming.

    Args:
        name(str, optional): Channel name. Defaults to None.
        latency_mode(str, optional): Channel latency mode. Use NORMAL to broadcast and deliver live video up to Full HD. Use LOW for near-real-time interaction with viewers. (Note: In the Amazon IVS console, LOW and NORMAL correspond to Ultra-low and Standard, respectively.) Default: LOW. Defaults to None.
        type_(str, optional): Channel type, which determines the allowable resolution and bitrate. If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately. Default: STANDARD. Valid values:    STANDARD: Multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Vertical resolution can be up to 1080 and bitrate can be up to 8.5 Mbps.    BASIC: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Vertical resolution can be up to 480 and bitrate can be up to 1.5 Mbps.  . Defaults to None.
        authorized(bool, optional): Whether the channel is private (enabled for playback authorization). Default: false. Defaults to None.
        recording_configuration_arn(str, optional): Recording-configuration ARN. Default: "" (empty string, recording is disabled). Defaults to None.
        tags(Dict, optional): Array of 1-50 maps, each of the form string:string (key:value). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.channel.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.channel.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="create_channel",
        op_kwargs={
            "name": name,
            "latencyMode": latency_mode,
            "type": type_,
            "authorized": authorized,
            "recordingConfigurationArn": recording_configuration_arn,
            "tags": tags,
        },
    )


async def delete(hub, ctx, arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified channel and its associated stream keys. If you try to delete a live channel, you will get an error (409 ConflictException). To delete a channel that is live, call StopStream, wait for the Amazon EventBridge "Stream End" event (to verify that the stream's state was changed from Live to Offline), then call DeleteChannel. (See  Using EventBridge with Amazon IVS.)

    Args:
        arn(str): ARN of the channel to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.channel.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.channel.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ivs", operation="delete_channel", op_kwargs={"arn": arn}
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.

    Args:
        arn(str): ARN of the channel for which the configuration is to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.channel.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.channel.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ivs", operation="get_channel", op_kwargs={"arn": arn}
    )


async def list_all(
    hub,
    ctx,
    filter_by_name: str = None,
    filter_by_recording_configuration_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about all channels in your account, in the AWS region where the API request is processed. This list can be filtered to match a specified name or recording-configuration ARN. Filters are mutually exclusive and cannot be used together. If you try to use both filters, you will get an error (409 ConflictException).

    Args:
        filter_by_name(str, optional): Filters the channel list to match the specified name. Defaults to None.
        filter_by_recording_configuration_arn(str, optional): Filters the channel list to match the specified recording-configuration ARN. Defaults to None.
        next_token(str, optional): The first channel to retrieve. This is used for pagination; see the nextToken response field. Defaults to None.
        max_results(int, optional): Maximum number of channels to return. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.channel.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.channel.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="list_channels",
        op_kwargs={
            "filterByName": filter_by_name,
            "filterByRecordingConfigurationArn": filter_by_recording_configuration_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    latency_mode: str = None,
    type_: str = None,
    authorized: bool = None,
    recording_configuration_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a channel's configuration. This does not affect an ongoing stream of this channel. You must stop and restart the stream for the changes to take effect.

    Args:
        arn(str): ARN of the channel to be updated.
        name(str, optional): Channel name. Defaults to None.
        latency_mode(str, optional): Channel latency mode. Use NORMAL to broadcast and deliver live video up to Full HD. Use LOW for near-real-time interaction with viewers. (Note: In the Amazon IVS console, LOW and NORMAL correspond to Ultra-low and Standard, respectively.). Defaults to None.
        type_(str, optional): Channel type, which determines the allowable resolution and bitrate. If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately. Valid values:    STANDARD: Multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Vertical resolution can be up to 1080 and bitrate can be up to 8.5 Mbps.    BASIC: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Vertical resolution can be up to 480 and bitrate can be up to 1.5 Mbps.  . Defaults to None.
        authorized(bool, optional): Whether the channel is private (enabled for playback authorization). Defaults to None.
        recording_configuration_arn(str, optional): Recording-configuration ARN. If this is set to an empty string, recording is disabled. A value other than an empty string indicates that recording is enabled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.channel.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.channel.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="update_channel",
        op_kwargs={
            "arn": arn,
            "name": name,
            "latencyMode": latency_mode,
            "type": type_,
            "authorized": authorized,
            "recordingConfigurationArn": recording_configuration_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, public_key_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a public key to CloudFront that you can use with signed URLs and signed cookies, or with field-level encryption.

    Args:
        public_key_config(Dict): A CloudFront public key configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.public_key.init.create(ctx, public_key_config=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.public_key.init.create public_key_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_public_key",
        op_kwargs={"PublicKeyConfig": public_key_config},
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Remove a public key you previously added to CloudFront.

    Args:
        id_(str): The ID of the public key you want to remove from CloudFront.
        if_match(str, optional): The value of the ETag header that you received when retrieving the public key identity to delete. For example: E2QWRUHAPOMQZL. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.public_key.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.public_key.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_public_key",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a public key.

    Args:
        id_(str): The identifier of the public key you are getting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.public_key.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.public_key.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_public_key",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all public keys that have been added to CloudFront for this account.

    Args:
        marker(str, optional): Use this when paginating results to indicate where to begin in your list of public keys. The results include public keys in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page's response (which is also the ID of the last public key on that page). . Defaults to None.
        max_items(str, optional): The maximum number of public keys you want in the response body. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.public_key.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.public_key.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_public_keys",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, public_key_config: Dict, id_: str, if_match: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update public key information. Note that the only value you can change is the comment.

    Args:
        public_key_config(Dict): A public key configuration.
        id_(str): The identifier of the public key that you are updating.
        if_match(str, optional): The value of the ETag header that you received when retrieving the public key to update. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.public_key.init.update(
                ctx, public_key_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.public_key.init.update public_key_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_public_key",
        op_kwargs={
            "PublicKeyConfig": public_key_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    hosted_zone_id: str,
    name: str,
    ttl: int,
    traffic_policy_id: str,
    traffic_policy_version: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates resource record sets in a specified hosted zone based on the settings in a specified traffic policy version. In addition, CreateTrafficPolicyInstance associates the resource record sets with a specified domain name (such as example.com) or subdomain name (such as www.example.com). Amazon Route 53 responds to DNS queries for the domain or subdomain name by using the resource record sets that CreateTrafficPolicyInstance created.

    Args:
        hosted_zone_id(str): The ID of the hosted zone that you want Amazon Route 53 to create resource record sets in by using the configuration in a traffic policy.
        name(str): The domain name (such as example.com) or subdomain name (such as www.example.com) for which Amazon Route 53 responds to DNS queries by using the resource record sets that Route 53 creates for this traffic policy instance.
        ttl(int): (Optional) The TTL that you want Amazon Route 53 to assign to all of the resource record sets that it creates in the specified hosted zone.
        traffic_policy_id(str): The ID of the traffic policy that you want to use to create resource record sets in the specified hosted zone.
        traffic_policy_version(int): The version of the traffic policy that you want to use to create resource record sets in the specified hosted zone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.init.create(
                ctx,
                hosted_zone_id=value,
                name=value,
                ttl=value,
                traffic_policy_id=value,
                traffic_policy_version=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.init.create hosted_zone_id=value, name=value, ttl=value, traffic_policy_id=value, traffic_policy_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_traffic_policy_instance",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "Name": name,
            "TTL": ttl,
            "TrafficPolicyId": traffic_policy_id,
            "TrafficPolicyVersion": traffic_policy_version,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a traffic policy instance and all of the resource record sets that Amazon Route 53 created when you created the instance.  In the Route 53 console, traffic policy instances are known as policy records.

    Args:
        id_(str): The ID of the traffic policy instance that you want to delete.   When you delete a traffic policy instance, Amazon Route 53 also deletes all of the resource record sets that were created when you created the traffic policy instance. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_traffic_policy_instance",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified traffic policy instance.  After you submit a CreateTrafficPolicyInstance or an UpdateTrafficPolicyInstance request, there's a brief delay while Amazon Route 53 creates the resource record sets that are specified in the traffic policy definition. For more information, see the State response element.   In the Route 53 console, traffic policy instances are known as policy records.

    Args:
        id_(str): The ID of the traffic policy instance that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_traffic_policy_instance",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    hosted_zone_id_marker: str = None,
    traffic_policy_instance_name_marker: str = None,
    traffic_policy_instance_type_marker: str = None,
    max_items: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the traffic policy instances that you created by using the current account.  After you submit an UpdateTrafficPolicyInstance request, there's a brief delay while Amazon Route 53 creates the resource record sets that are specified in the traffic policy definition. For more information, see the State response element.  Route 53 returns a maximum of 100 items in each response. If you have a lot of traffic policy instances, you can use the MaxItems parameter to list them in groups of up to 100.

    Args:
        hosted_zone_id_marker(str, optional): If the value of IsTruncated in the previous response was true, you have more traffic policy instances. To get more traffic policy instances, submit another ListTrafficPolicyInstances request. For the value of HostedZoneId, specify the value of HostedZoneIdMarker from the previous response, which is the hosted zone ID of the first traffic policy instance in the next group of traffic policy instances. If the value of IsTruncated in the previous response was false, there are no more traffic policy instances to get. Defaults to None.
        traffic_policy_instance_name_marker(str, optional): If the value of IsTruncated in the previous response was true, you have more traffic policy instances. To get more traffic policy instances, submit another ListTrafficPolicyInstances request. For the value of trafficpolicyinstancename, specify the value of TrafficPolicyInstanceNameMarker from the previous response, which is the name of the first traffic policy instance in the next group of traffic policy instances. If the value of IsTruncated in the previous response was false, there are no more traffic policy instances to get. Defaults to None.
        traffic_policy_instance_type_marker(str, optional): If the value of IsTruncated in the previous response was true, you have more traffic policy instances. To get more traffic policy instances, submit another ListTrafficPolicyInstances request. For the value of trafficpolicyinstancetype, specify the value of TrafficPolicyInstanceTypeMarker from the previous response, which is the type of the first traffic policy instance in the next group of traffic policy instances. If the value of IsTruncated in the previous response was false, there are no more traffic policy instances to get. Defaults to None.
        max_items(str, optional): The maximum number of traffic policy instances that you want Amazon Route 53 to return in response to a ListTrafficPolicyInstances request. If you have more than MaxItems traffic policy instances, the value of the IsTruncated element in the response is true, and the values of HostedZoneIdMarker, TrafficPolicyInstanceNameMarker, and TrafficPolicyInstanceTypeMarker represent the first traffic policy instance in the next group of MaxItems traffic policy instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_traffic_policy_instances",
        op_kwargs={
            "HostedZoneIdMarker": hosted_zone_id_marker,
            "TrafficPolicyInstanceNameMarker": traffic_policy_instance_name_marker,
            "TrafficPolicyInstanceTypeMarker": traffic_policy_instance_type_marker,
            "MaxItems": max_items,
        },
    )


async def update(
    hub, ctx, id_: str, ttl: int, traffic_policy_id: str, traffic_policy_version: int
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the resource record sets in a specified hosted zone that were created based on the settings in a specified traffic policy version. When you update a traffic policy instance, Amazon Route 53 continues to respond to DNS queries for the root resource record set name (such as example.com) while it replaces one group of resource record sets with another. Route 53 performs the following operations:   Route 53 creates a new group of resource record sets based on the specified traffic policy. This is true regardless of how significant the differences are between the existing resource record sets and the new resource record sets.    When all of the new resource record sets have been created, Route 53 starts to respond to DNS queries for the root resource record set name (such as example.com) by using the new resource record sets.   Route 53 deletes the old group of resource record sets that are associated with the root resource record set name.

    Args:
        id_(str): The ID of the traffic policy instance that you want to update.
        ttl(int): The TTL that you want Amazon Route 53 to assign to all of the updated resource record sets.
        traffic_policy_id(str): The ID of the traffic policy that you want Amazon Route 53 to use to update resource record sets for the specified traffic policy instance.
        traffic_policy_version(int): The version of the traffic policy that you want Amazon Route 53 to use to update resource record sets for the specified traffic policy instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.init.update(
                ctx, id_=value, ttl=value, traffic_policy_id=value, traffic_policy_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.init.update id_=value, ttl=value, traffic_policy_id=value, traffic_policy_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="update_traffic_policy_instance",
        op_kwargs={
            "Id": id_,
            "TTL": ttl,
            "TrafficPolicyId": traffic_policy_id,
            "TrafficPolicyVersion": traffic_policy_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, architecture: str, greengrass_group_id: str, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a robot.

    Args:
        name(str): The name for the robot.
        architecture(str): The target architecture of the robot.
        greengrass_group_id(str): The Greengrass group id.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the robot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.create(
                ctx, name=value, architecture=value, greengrass_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.create name=value, architecture=value, greengrass_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_robot",
        op_kwargs={
            "name": name,
            "architecture": architecture,
            "greengrassGroupId": greengrass_group_id,
            "tags": tags,
        },
    )


async def delete(hub, ctx, robot: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a robot.

    Args:
        robot(str): The Amazon Resource Name (ARN) of the robot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.delete(ctx, robot=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.delete robot=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="delete_robot",
        op_kwargs={"robot": robot},
    )


async def deregister(hub, ctx, fleet: str, robot: str) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters a robot.

    Args:
        fleet(str): The Amazon Resource Name (ARN) of the fleet.
        robot(str): The Amazon Resource Name (ARN) of the robot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.deregister(ctx, fleet=value, robot=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.deregister fleet=value, robot=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="deregister_robot",
        op_kwargs={"fleet": fleet, "robot": robot},
    )


async def describe(hub, ctx, robot: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a robot.

    Args:
        robot(str): The Amazon Resource Name (ARN) of the robot to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.describe(ctx, robot=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.describe robot=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_robot",
        op_kwargs={"robot": robot},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of robots. You can optionally provide filters to retrieve specific robots.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListRobots again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListRobots only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListRobots request with the returned nextToken value. This value can be between 1 and 200. If this parameter is not used, then ListRobots returns up to 200 results and a nextToken value if applicable. . Defaults to None.
        filters(List, optional): Optional filters to limit results. The filter names status and fleetName are supported. When filtering, you must use the complete value of the filtered item. You can use up to three filters, but they must be for the same named item. For example, if you are looking for items with the status Registered or the status Available. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_robots",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )


async def register(hub, ctx, fleet: str, robot: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers a robot with a fleet.

    Args:
        fleet(str): The Amazon Resource Name (ARN) of the fleet.
        robot(str): The Amazon Resource Name (ARN) of the robot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.robot.init.register(ctx, fleet=value, robot=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.robot.init.register fleet=value, robot=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="register_robot",
        op_kwargs={"fleet": fleet, "robot": robot},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    application_name: str = None,
    template_name: str = None,
    environment_name: str = None,
    solution_stack_name: str = None,
    platform_arn: str = None,
    options: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines. The description includes the values the options, their default values, and an indication of the required action on a running environment if an option value is changed.

    Args:
        application_name(str, optional): The name of the application associated with the configuration template or environment. Only needed if you want to describe the configuration options associated with either the configuration template or environment. Defaults to None.
        template_name(str, optional): The name of the configuration template whose configuration options you want to describe. Defaults to None.
        environment_name(str, optional): The name of the environment whose configuration options you want to describe. Defaults to None.
        solution_stack_name(str, optional): The name of the solution stack whose configuration options you want to describe. Defaults to None.
        platform_arn(str, optional): The ARN of the custom platform. Defaults to None.
        options(List, optional): If specified, restricts the descriptions to only the specified options. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.option.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.option.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_configuration_options",
        op_kwargs={
            "ApplicationName": application_name,
            "TemplateName": template_name,
            "EnvironmentName": environment_name,
            "SolutionStackName": solution_stack_name,
            "PlatformArn": platform_arn,
            "Options": options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    namespace: str = None,
    metric_name: str = None,
    dimensions: List = None,
    next_token: str = None,
    recently_active: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the specified metrics. You can use the returned metrics with GetMetricData or GetMetricStatistics to obtain statistical data. Up to 500 results are returned for any one call. To retrieve additional results, use the returned token with subsequent calls. After you create a metric, allow up to 15 minutes before the metric appears. You can see statistics about the metric sooner by using GetMetricData or GetMetricStatistics.  ListMetrics doesn't return information about metrics if those metrics haven't reported data in the past two weeks. To retrieve those metrics, use GetMetricData or GetMetricStatistics.

    Args:
        namespace(str, optional): The metric namespace to filter against. Only the namespace that matches exactly will be returned. Defaults to None.
        metric_name(str, optional): The name of the metric to filter against. Only the metrics with names that match exactly will be returned. Defaults to None.
        dimensions(List, optional): The dimensions to filter against. Only the dimensions that match exactly will be returned. Defaults to None.
        next_token(str, optional): The token returned by a previous call to indicate that there is more data available. Defaults to None.
        recently_active(str, optional): To filter the results to show only metrics that have had data points published in the past three hours, specify this parameter with a value of PT3H. This is the only valid value for this parameter. The results that are returned are an approximation of the value you specify. There is a low probability that the returned results include metrics with last published data as much as 40 minutes more than the specified time interval. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="list_metrics",
        op_kwargs={
            "Namespace": namespace,
            "MetricName": metric_name,
            "Dimensions": dimensions,
            "NextToken": next_token,
            "RecentlyActive": recently_active,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def cancel(hub, ctx, stack_name: str, client_request_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Cancels an update on the specified stack. If the call completes successfully, the stack rolls back the update and reverts to the previous stack configuration.  You can cancel only stacks that are in the UPDATE_IN_PROGRESS state.

    Args:
        stack_name(str): The name or the unique stack ID that is associated with the stack.
        client_request_token(str, optional): A unique identifier for this CancelUpdateStack request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to cancel an update on a stack with the same name. You might retry CancelUpdateStack requests to ensure that CloudFormation successfully received them. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.update.stack.cancel(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.update.stack.cancel stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="cancel_update_stack",
        op_kwargs={"StackName": stack_name, "ClientRequestToken": client_request_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def batch(hub, ctx, domain_name: str, items: List) -> None:
    r"""
    **Autogenerated function**

     The BatchPutAttributes operation creates or replaces attributes within one or more items. By using this operation, the client can perform multiple PutAttribute operation with a single call. This helps yield savings in round trips and latencies, enabling Amazon SimpleDB to optimize requests and generally produce better throughput.   The client may specify the item name with the Item.X.ItemName parameter. The client may specify new attributes using a combination of the Item.X.Attribute.Y.Name and Item.X.Attribute.Y.Value parameters. The client may specify the first attribute for the first item using the parameters Item.0.Attribute.0.Name and Item.0.Attribute.0.Value, and for the second attribute for the first item by the parameters Item.0.Attribute.1.Name and Item.0.Attribute.1.Value, and so on.   Attributes are uniquely identified within an item by their name/value combination. For example, a single item can have the attributes { "first_name", "first_value" } and { "first_name", "second_value" }. However, it cannot have two attribute instances where both the Item.X.Attribute.Y.Name and Item.X.Attribute.Y.Value are the same.   Optionally, the requester can supply the Replace parameter for each individual value. Setting this value to true will cause the new attribute values to replace the existing attribute values. For example, if an item I has the attributes { 'a', '1' }, { 'b', '2'} and { 'b', '3' } and the requester does a BatchPutAttributes of {'I', 'b', '4' } with the Replace parameter set to true, the final attributes of the item will be { 'a', '1' } and { 'b', '4' }, replacing the previous values of the 'b' attribute with the new value.   This operation is vulnerable to exceeding the maximum URL size when making a REST request using the HTTP GET method. This operation does not support conditions using Expected.X.Name, Expected.X.Value, or Expected.X.Exists.   You can execute multiple BatchPutAttributes operations and other operations in parallel. However, large numbers of concurrent BatchPutAttributes calls can result in Service Unavailable (503) responses.   The following limitations are enforced for this operation:  256 attribute name-value pairs per item 1 MB request size 1 billion attributes per domain 10 GB of total user data storage per domain 25 item limit per BatchPutAttributes operation

    Args:
        domain_name(str): The name of the domain in which the attributes are being stored.
        items(List): A list of items on which to perform the operation.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sdb.put_attribute.batch(ctx, domain_name=value, items=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sdb.put_attribute.batch domain_name=value, items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sdb",
        operation="batch_put_attributes",
        op_kwargs={"DomainName": domain_name, "Items": items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, key_id: str, primary_region: str) -> None:
    r"""
    **Autogenerated function**

    Changes the primary key of a multi-Region key.  This operation changes the replica key in the specified Region to a primary key and changes the former primary key to a replica key. For example, suppose you have a primary key in us-east-1 and a replica key in eu-west-2. If you run UpdatePrimaryRegion with a PrimaryRegion value of eu-west-2, the primary key is now the key in eu-west-2, and the key in us-east-1 becomes a replica key. For details, see  This operation supports multi-Region keys, an AWS KMS feature that lets you create multiple interoperable CMKs in different AWS Regions. Because these CMKs have the same key ID, key material, and other metadata, you can use them to encrypt data in one AWS Region and decrypt it in a different AWS Region without making a cross-Region call or exposing the plaintext data. For more information about multi-Region keys, see Using multi-Region keys in the AWS Key Management Service Developer Guide. The primary key of a multi-Region key is the source for properties that are always shared by primary and replica keys, including the key material, key ID, key spec, key usage, key material origin, and automatic key rotation. It's the only key that can be replicated. You cannot delete the primary key until all replicas are deleted. The key ID and primary Region that you specify uniquely identify the replica key that will become the primary key. The primary Region must already have a replica key. This operation does not create a CMK in the specified Region. To find the replica keys, use the DescribeKey operation on the primary key or any replica key. To create a replica key, use the ReplicateKey operation. You can run this operation while using the affected multi-Region keys in cryptographic operations. This operation should not delay, interrupt, or cause failures in cryptographic operations.  Even after this operation completes, the process of updating the primary Region might still be in progress for a few more seconds. Operations such as DescribeKey might display both the old and new primary keys as replicas. The old and new primary keys have a transient key state of Updating. The original key state is restored when the update is complete. While the key state is Updating, you can use the keys in cryptographic operations, but you cannot replicate the new primary key or perform certain management operations, such as enabling or disabling these keys. For details about the Updating key state, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide. This operation does not return any output. To verify that primary key is changed, use the DescribeKey operation.  Cross-account use: No. You cannot use this operation in a different AWS account.   Required permissions:     kms:UpdatePrimaryRegion on the current primary CMK (in the primary CMK's Region). Include this permission primary CMK's key policy.    kms:UpdatePrimaryRegion on the current replica CMK (in the replica CMK's Region). Include this permission in the replica CMK's key policy.    Related operations     CreateKey     ReplicateKey

    Args:
        key_id(str): Identifies the current primary key. When the operation completes, this CMK will be a replica key. Specify the key ID or key ARN of a multi-Region primary key. For example:   Key ID: mrk-1234abcd12ab34cd56ef1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/mrk-1234abcd12ab34cd56ef1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        primary_region(str): The AWS Region of the new primary key. Enter the Region ID, such as us-east-1 or ap-southeast-2. There must be an existing replica key in this Region.  When the operation completes, the multi-Region key in this Region will be the primary key.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.primary_region.update(
                ctx, key_id=value, primary_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.primary_region.update key_id=value, primary_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="update_primary_region",
        op_kwargs={"KeyId": key_id, "PrimaryRegion": primary_region},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    spec: str,
    template_major_version: str,
    template_name: str,
    branch_name: str = None,
    description: str = None,
    repository_connection_arn: str = None,
    repository_id: str = None,
    tags: List = None,
    template_minor_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an AWS Proton service. An AWS Proton service is an instantiation of a service template and often includes several service instances and pipeline. For more information, see Services in the AWS Proton Administrator Guide and Services in the AWS Proton User Guide.

    Args:
        branch_name(str, optional): The name of the code repository branch that holds the code that's deployed in AWS Proton. Don't include this parameter if your service template doesn't include a service pipeline. Defaults to None.
        description(str, optional): A description of the AWS Proton service. Defaults to None.
        name(str): The service name.
        repository_connection_arn(str, optional): The Amazon Resource Name (ARN) of the repository connection. For more information, see Set up repository connection in the AWS Proton Administrator Guide and Setting up with AWS Proton in the AWS Proton User Guide. Don't include this parameter if your service template doesn't include a service pipeline. Defaults to None.
        repository_id(str, optional): The ID of the code repository. Don't include this parameter if your service template doesn't include a service pipeline. Defaults to None.
        spec(str): A link to a spec file that provides inputs as defined in the service template bundle schema file. The spec file is in YAML format. Don’t include pipeline inputs in the spec if your service template doesn’t include a service pipeline. For more information, see Create a service in the AWS Proton Administrator Guide and Create a service in the AWS Proton User Guide.
        tags(List, optional): Create tags for your service. For more information, see AWS Proton resources and tagging in the AWS Proton Administrator Guide or AWS Proton User Guide. Defaults to None.
        template_major_version(str): The ID of the major version of the service template that was used to create the service.
        template_minor_version(str, optional): The ID of the minor version of the service template that was used to create the service. Defaults to None.
        template_name(str): The name of the service template that's used to create the service.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.init.create(
                ctx, name=value, spec=value, template_major_version=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.init.create name=value, spec=value, template_major_version=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_service",
        op_kwargs={
            "branchName": branch_name,
            "description": description,
            "name": name,
            "repositoryConnectionArn": repository_connection_arn,
            "repositoryId": repository_id,
            "spec": spec,
            "tags": tags,
            "templateMajorVersion": template_major_version,
            "templateMinorVersion": template_minor_version,
            "templateName": template_name,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a service.

    Args:
        name(str): The name of the service to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="proton", operation="delete_service", op_kwargs={"name": name}
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get detail data for a service.

    Args:
        name(str): The name of the service that you want to get the detail data for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="proton", operation="get_service", op_kwargs={"name": name}
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List services with summaries of detail data.

    Args:
        max_results(int, optional): The maximum number of services to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next service in the array of services, after the list of services that was previously requested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_services",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, name: str, description: str = None, spec: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Edit a service description or use a spec to add and delete service instances.  Existing service instances and the service pipeline can't be edited using this API. They can only be deleted.  Use the description parameter to modify the description. Edit the spec parameter to add or delete instances.

    Args:
        description(str, optional): The edited service description. Defaults to None.
        name(str): The name of the service to edit.
        spec(str, optional): Lists the service instances to add and the existing service instances to remain. Omit the existing service instances to delete from the list. Don't include edits to the existing service instances or pipeline. For more information, see Edit a service in the AWS Proton Administrator Guide or the AWS Proton User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_service",
        op_kwargs={"description": description, "name": name, "spec": spec},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration settings for publishing findings to Security Hub.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.publication_configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.publication_configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_findings_publication_configuration",
        op_kwargs={},
    )


async def put(
    hub, ctx, client_token: str = None, security_hub_configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration settings for publishing findings to Security Hub.

    Args:
        client_token(str, optional): A unique, case-sensitive token that you provide to ensure the idempotency of the request. Defaults to None.
        security_hub_configuration(Dict, optional): The configuration settings that determine which findings to publish to Security Hub. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.finding.publication_configuration.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.finding.publication_configuration.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="put_findings_publication_configuration",
        op_kwargs={
            "clientToken": client_token,
            "securityHubConfiguration": security_hub_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, identity_pool_id: str, identity_id: str, dataset_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specific dataset. The dataset will be deleted permanently, and the action can't be undone. Datasets that this dataset was merged with will no longer report the merge. Any subsequent operation on this dataset will result in a ResourceNotFoundException. This API can be called with temporary user credentials provided by Cognito Identity or with developer credentials.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        dataset_name(str): A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.dataset.delete(
                ctx, identity_pool_id=value, identity_id=value, dataset_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.dataset.delete identity_pool_id=value, identity_id=value, dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="delete_dataset",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DatasetName": dataset_name,
        },
    )


async def describe(
    hub, ctx, identity_pool_id: str, identity_id: str, dataset_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets meta data about a dataset by identity and dataset name. With Amazon Cognito Sync, each identity has access only to its own data. Thus, the credentials used to make this API call need to have access to the identity data. This API can be called with temporary user credentials provided by Cognito Identity or with developer credentials. You should use Cognito Identity credentials to make this API call.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        dataset_name(str): A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.dataset.describe(
                ctx, identity_pool_id=value, identity_id=value, dataset_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.dataset.describe identity_pool_id=value, identity_id=value, dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="describe_dataset",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DatasetName": dataset_name,
        },
    )


async def list_all(
    hub,
    ctx,
    identity_pool_id: str,
    identity_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists datasets for an identity. With Amazon Cognito Sync, each identity has access only to its own data. Thus, the credentials used to make this API call need to have access to the identity data. ListDatasets can be called with temporary user credentials provided by Cognito Identity or with developer credentials. You should use the Cognito Identity credentials to make this API call.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        next_token(str, optional): A pagination token for obtaining the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.dataset.list_all(
                ctx, identity_pool_id=value, identity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.dataset.list_all identity_pool_id=value, identity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="list_datasets",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, project_id: str, asset_ids: List, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a group (batch) of assets from an IoT SiteWise Monitor project.

    Args:
        project_id(str): The ID of the project from which to disassociate the assets.
        asset_ids(List): The IDs of the assets to be disassociated from the project.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.disassociate_project_asset.batch(
                ctx, project_id=value, asset_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.disassociate_project_asset.batch project_id=value, asset_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="batch_disassociate_project_assets",
        op_kwargs={
            "projectId": project_id,
            "assetIds": asset_ids,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    producer_arn: str = None,
    status: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of datashares when the account identifier being called is a producer account identifier.

    Args:
        producer_arn(str, optional): The Amazon Resource Name (ARN) of the producer that returns in the list of datashares. Defaults to None.
        status(str, optional): An identifier giving the status of a datashare in the producer. If this field is specified, Amazon Redshift returns the list of datashares that have the specified status. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. . Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataSharesForProducer request exceed the value specified in MaxRecords, AWS returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.for_.producer.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.for_.producer.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_data_shares_for_producer",
        op_kwargs={
            "ProducerArn": producer_arn,
            "Status": status,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def notify(hub, ctx, file_share_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Sends you notification through CloudWatch Events when all files written to your file share have been uploaded to Amazon S3. Storage Gateway can send a notification through Amazon CloudWatch Events when all files written to your file share up to that point in time have been uploaded to Amazon S3. These files include files written to the file share up to the time that you make a request for notification. When the upload is done, Storage Gateway sends you notification through an Amazon CloudWatch Event. You can configure CloudWatch Events to send the notification through event targets such as Amazon SNS or Lambda function. This operation is only supported for S3 File Gateways. For more information, see Getting file upload notification in the Storage Gateway User Guide.

    Args:
        file_share_arn(str): The Amazon Resource Name (ARN) of the file share.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.when_uploaded.notify(ctx, file_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.when_uploaded.notify file_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="notify_when_uploaded",
        op_kwargs={"FileShareARN": file_share_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def publish(hub, ctx, environment_name: str, metric_data: List) -> Dict:
    r"""
    **Autogenerated function**

    An operation for publishing metrics from the customers to the Ops plane.

    Args:
        environment_name(str): Publishes environment metric data to Amazon CloudWatch.
        metric_data(List): Publishes metric data points to Amazon CloudWatch. CloudWatch associates the data points with the specified metrica.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mwaa.metric.publish(
                ctx, environment_name=value, metric_data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mwaa.metric.publish environment_name=value, metric_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mwaa",
        operation="publish_metrics",
        op_kwargs={"EnvironmentName": environment_name, "MetricData": metric_data},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub,
    ctx,
    repository_name: str,
    branch_name: str,
    file_path: str,
    parent_commit_id: str,
    keep_empty_folders: bool = None,
    commit_message: str = None,
    name: str = None,
    email: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified file from a specified branch. A commit is created on the branch that contains the revision. The file still exists in the commits earlier to the commit that contains the deletion.

    Args:
        repository_name(str): The name of the repository that contains the file to delete.
        branch_name(str): The name of the branch where the commit that deletes the file is made.
        file_path(str): The fully qualified path to the file that to be deleted, including the full name and extension of that file. For example, /examples/file.md is a fully qualified path to a file named file.md in a folder named examples.
        parent_commit_id(str): The ID of the commit that is the tip of the branch where you want to create the commit that deletes the file. This must be the HEAD commit for the branch. The commit that deletes the file is created from this commit ID.
        keep_empty_folders(bool, optional): If a file is the only object in the folder or directory, specifies whether to delete the folder or directory that contains the file. By default, empty folders are deleted. This includes empty folders that are part of the directory structure. For example, if the path to a file is dir1/dir2/dir3/dir4, and dir2 and dir3 are empty, deleting the last file in dir4 also deletes the empty folders dir4, dir3, and dir2. Defaults to None.
        commit_message(str, optional): The commit message you want to include as part of deleting the file. Commit messages are limited to 256 KB. If no message is specified, a default message is used. Defaults to None.
        name(str, optional): The name of the author of the commit that deletes the file. If no name is specified, the user's ARN is used as the author name and committer name. Defaults to None.
        email(str, optional): The email address for the commit that deletes the file. If no email address is specified, the email address is left blank. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.file.delete(
                ctx,
                repository_name=value,
                branch_name=value,
                file_path=value,
                parent_commit_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.file.delete repository_name=value, branch_name=value, file_path=value, parent_commit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_file",
        op_kwargs={
            "repositoryName": repository_name,
            "branchName": branch_name,
            "filePath": file_path,
            "parentCommitId": parent_commit_id,
            "keepEmptyFolders": keep_empty_folders,
            "commitMessage": commit_message,
            "name": name,
            "email": email,
        },
    )


async def get(
    hub, ctx, repository_name: str, file_path: str, commit_specifier: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the base-64 encoded contents of a specified file and its metadata.

    Args:
        repository_name(str): The name of the repository that contains the file.
        commit_specifier(str, optional): The fully quaified reference that identifies the commit that contains the file. For example, you can specify a full commit ID, a tag, a branch name, or a reference such as refs/heads/master. If none is provided, the head commit is used. Defaults to None.
        file_path(str): The fully qualified path to the file, including the full name and extension of the file. For example, /examples/file.md is the fully qualified path to a file named file.md in a folder named examples.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.file.get(ctx, repository_name=value, file_path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.file.get repository_name=value, file_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_file",
        op_kwargs={
            "repositoryName": repository_name,
            "commitSpecifier": commit_specifier,
            "filePath": file_path,
        },
    )


async def put(
    hub,
    ctx,
    repository_name: str,
    branch_name: str,
    file_content: bytes,
    file_path: str,
    file_mode: str = None,
    parent_commit_id: str = None,
    commit_message: str = None,
    name: str = None,
    email: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates a file in a branch in an AWS CodeCommit repository, and generates a commit for the addition in the specified branch.

    Args:
        repository_name(str): The name of the repository where you want to add or update the file.
        branch_name(str): The name of the branch where you want to add or update the file. If this is an empty repository, this branch is created.
        file_content(bytes): The content of the file, in binary object format. .
        file_path(str): The name of the file you want to add or update, including the relative path to the file in the repository.  If the path does not currently exist in the repository, the path is created as part of adding the file. .
        file_mode(str, optional): The file mode permissions of the blob. Valid file mode permissions are listed here. Defaults to None.
        parent_commit_id(str, optional): The full commit ID of the head commit in the branch where you want to add or update the file. If this is an empty repository, no commit ID is required. If this is not an empty repository, a commit ID is required.  The commit ID must match the ID of the head commit at the time of the operation. Otherwise, an error occurs, and the file is not added or updated. Defaults to None.
        commit_message(str, optional): A message about why this file was added or updated. Although it is optional, a message makes the commit history for your repository more useful. Defaults to None.
        name(str, optional): The name of the person adding or updating the file. Although it is optional, a name makes the commit history for your repository more useful. Defaults to None.
        email(str, optional): An email address for the person adding or updating the file. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.file.put(
                ctx, repository_name=value, branch_name=value, file_content=value, file_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.file.put repository_name=value, branch_name=value, file_content=value, file_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="put_file",
        op_kwargs={
            "repositoryName": repository_name,
            "branchName": branch_name,
            "fileContent": file_content,
            "filePath": file_path,
            "fileMode": file_mode,
            "parentCommitId": parent_commit_id,
            "commitMessage": commit_message,
            "name": name,
            "email": email,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, savings_plan_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the queued purchase for the specified Savings Plan.

    Args:
        savings_plan_id(str): The ID of the Savings Plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.savingsplan.queued_saving_plan.delete(
                ctx, savings_plan_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.savingsplan.queued_saving_plan.delete savings_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="savingsplans",
        operation="delete_queued_savings_plan",
        op_kwargs={"savingsPlanId": savings_plan_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, email_identity: str, signing_enabled: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Used to enable or disable DKIM authentication for an email identity.

    Args:
        email_identity(str): The email identity that you want to change the DKIM settings for.
        signing_enabled(bool, optional): Sets the DKIM signing configuration for the identity. When you set this value true, then the messages that are sent from the identity are signed using DKIM. If you set this value to false, your messages are sent without DKIM signing. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.dkim.attribute.put_multiple(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.dkim.attribute.put_multiple email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_email_identity_dkim_attributes",
        op_kwargs={"EmailIdentity": email_identity, "SigningEnabled": signing_enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deprecate(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deprecates the specified domain. After a domain has been deprecated it cannot be used to create new workflow executions or register new types. However, you can still use visibility actions on this domain. Deprecating a domain also deprecates all activity and workflow types registered in the domain. Executions that were started before the domain was deprecated continues to run.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        name(str): The name of the domain to deprecate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.domain.deprecate(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.domain.deprecate name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="swf", operation="deprecate_domain", op_kwargs={"name": name}
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified domain, including description and status.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        name(str): The name of the domain to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.domain.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.domain.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="swf", operation="describe_domain", op_kwargs={"name": name}
    )


async def list_all(
    hub,
    ctx,
    registration_status: str,
    next_page_token: str = None,
    maximum_page_size: int = None,
    reverse_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of domains registered in the account. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains. The element must be set to arn:aws:swf::AccountID:domain/*, where AccountID is the account ID, with no dashes.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        next_page_token(str, optional): If NextPageToken is returned there are more results available. The value of NextPageToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 60 seconds. Using an expired pagination token will return a 400 error: "Specified token has exceeded its maximum lifetime".  The configured maximumPageSize determines how many results can be returned in a single call. . Defaults to None.
        registration_status(str): Specifies the registration status of the domains to list.
        maximum_page_size(int, optional): The maximum number of results that are returned per call. Use nextPageToken to obtain further pages of results. . Defaults to None.
        reverse_order(bool, optional): When set to true, returns the results in reverse order. By default, the results are returned in ascending alphabetical order by name of the domains. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.domain.list_all(ctx, registration_status=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.domain.list_all registration_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="list_domains",
        op_kwargs={
            "nextPageToken": next_page_token,
            "registrationStatus": registration_status,
            "maximumPageSize": maximum_page_size,
            "reverseOrder": reverse_order,
        },
    )


async def register(
    hub,
    ctx,
    name: str,
    workflow_execution_retention_period_in_days: str,
    description: str = None,
    tags: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Registers a new domain.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   You cannot use an IAM policy to control domain access for this action. The name of the domain being registered is available as the resource of this action.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        name(str): Name of the domain to register. The name must be unique in the region that the domain is registered in. The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        description(str, optional): A text description of the domain. Defaults to None.
        workflow_execution_retention_period_in_days(str): The duration (in days) that records and histories of workflow executions on the domain should be kept by the service. After the retention period, the workflow execution isn't available in the results of visibility calls. If you pass the value NONE or 0 (zero), then the workflow execution history isn't retained. As soon as the workflow execution completes, the execution record and its history are deleted. The maximum workflow execution retention period is 90 days. For more information about Amazon SWF service limits, see: Amazon SWF Service Limits in the Amazon SWF Developer Guide.
        tags(List, optional): Tags to be added when registering a domain. Tags may only contain unicode letters, digits, whitespace, or these symbols: _ . : / = + - @. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.domain.register(
                ctx, name=value, workflow_execution_retention_period_in_days=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.domain.register name=value, workflow_execution_retention_period_in_days=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="register_domain",
        op_kwargs={
            "name": name,
            "description": description,
            "workflowExecutionRetentionPeriodInDays": workflow_execution_retention_period_in_days,
            "tags": tags,
        },
    )


async def undeprecate(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Undeprecates a previously deprecated domain. After a domain has been undeprecated it can be used to create new workflow executions or register new types.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        name(str): The name of the domain of the deprecated workflow type.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.domain.undeprecate(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.domain.undeprecate name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="undeprecate_domain",
        op_kwargs={"name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the tags assigned to the specified applied quota.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the applied quota for which you want to list tags. You can get this information by using the Service Quotas console, or by listing the quotas using the list-service-quotas AWS CLI command or the ListServiceQuotas AWS API operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceARN": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    security_group_rule_ids: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your security group rules.

    Args:
        filters(List, optional): One or more filters.    group-id - The ID of the security group.    security-group-rule-id - The ID of the security group rule.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.  . Defaults to None.
        security_group_rule_ids(List, optional): The IDs of the security group rules. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned NextToken value. This value can be between 5 and 1000. If this parameter is not specified, then all results are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.rule.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.rule.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_security_group_rules",
        op_kwargs={
            "Filters": filters,
            "SecurityGroupRuleIds": security_group_rule_ids,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def modify(
    hub, ctx, group_id: str, security_group_rules: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the rules of a security group.

    Args:
        group_id(str): The ID of the security group.
        security_group_rules(List): Information about the security group properties to update.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.rule.init.modify(
                ctx, group_id=value, security_group_rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.rule.init.modify group_id=value, security_group_rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_security_group_rules",
        op_kwargs={
            "GroupId": group_id,
            "SecurityGroupRules": security_group_rules,
            "DryRun": dry_run,
        },
    )
